@@ -24,6 +24,7 @@ pub use crate::trait_impls::*;
 use crate::utils::reverse_copy;
 use core::cmp::{Ord, PartialEq};
 use core::intrinsics;
+use core::iter::FromIterator;
 use core::marker::PhantomData;
 use core::mem::MaybeUninit;
 use core::ops::{
@@ -912,17 +913,16 @@ impl<T, const N: usize> StaticVec<T, N> {
     // a bit confused by math operations done on const generic values
     // in return types it seems.
     let mut res_ptr = res.as_mut_ptr() as *mut T;
-    let mut self_ptr = self.as_ptr();
-    for _ in 0..self.length - 1 {
+    let mut i = 0;
+    while i < self.length - 1 {
       unsafe {
-        res_ptr.write(self_ptr.read());
-        res_ptr = res_ptr.offset(1);
-        res_ptr.write(separator);
-        res_ptr = res_ptr.offset(1);
-        self_ptr = self_ptr.offset(1);
+        res_ptr.write(self.ptr_at_unchecked(i).read());
+        res_ptr.offset(1).write(separator);
+        res_ptr = res_ptr.offset(2);
+        i += 1
       }
     }
-    unsafe { res_ptr.write(self_ptr.read()) };
+    unsafe { res_ptr.write(self.ptr_at_unchecked(i).read()) };
     res.length = (self.length * 2) - 1;
     res
   }
@@ -1259,6 +1259,37 @@ impl<T, const N: usize> StaticVec<T, N> {
     res
   }
 
+  /// Returns a new StaticVec representing the union of `self` and `other` (that is, the full
+  /// contents of both `self` and `other`, minus any duplicates.)
+  ///
+  /// The `N2` parameter does not need to be provided explicitly, and can be inferred from `other`
+  /// itself.
+  ///
+  /// Locally requires that `T` implements [`Clone`](core::clone::Clone) to avoid soundness issues
+  /// while accommodating for more types than [`Copy`](core::marker::Copy) would appropriately for
+  /// this function, and [`PartialEq`](core::cmp::PartialEq) to make the item comparisons possible.
+  ///
+  /// Example usage:
+  /// ```
+  /// assert_eq!(
+  ///   staticvec![1, 2, 3].union(&staticvec![4, 2, 3, 4]),
+  ///   [1, 2, 3, 4],
+  /// );
+  /// ```
+  #[inline]
+  pub fn union<const N2: usize>(&self, other: &StaticVec<T, N2>) -> StaticVec<T, { N + N2 }>
+  where T: Clone + PartialEq {
+    if self.length <= other.length {
+      let mut res = StaticVec::from_iter(self.iter().chain(other.difference(self).iter()).cloned());
+      res.dedup();
+      res
+    } else {
+      let mut res = StaticVec::from_iter(other.iter().chain(self.difference(other).iter()).cloned());
+      res.dedup();
+      res
+    }
+  }
+
   /// A concept borrowed from the widely-used `SmallVec` crate, this function
   /// returns a tuple consisting of a constant pointer to the first element of the StaticVec,
   /// the length of the StaticVec, and the capacity of the StaticVec.
