@@ -33,12 +33,10 @@ macro_rules! impl_extend {
     fn extend<I: IntoIterator<Item = $type>>(&mut self, iter: I) {
       let mut it = iter.into_iter();
       let mut i = self.length;
-      let mut p = unsafe { self.as_mut_ptr().add(i) };
       while i < N {
         if let Some($var_a) = it.next() {
           unsafe {
-            p.write($var_b);
-            p = p.offset(1);
+            self.mut_ptr_at_unchecked(i).write($var_b);
           }
         } else {
           break;
